# Generated by Django 3.0.8 on 2020-08-03 16:00

from django.db import migrations, models
import castellum.utils.fields
import django.utils.timezone


def migrate_data(apps, schema_editor):
    Participation = apps.get_model('recruitment', 'Participation')
    ParticipationRevision = apps.get_model('recruitment', 'ParticipationRevision')

    others = ParticipationRevision.objects\
        .filter(current_id=models.OuterRef('id'))\
        .exclude(status=models.OuterRef('status'))
    other_status_at = others.order_by('-created_at').values('created_at')[:1]

    participations = Participation.objects.annotate(
        old_updated_at=models.Max('revisions__created_at'),
        old_created_at=models.Min('revisions__created_at'),
        other_status_at=models.Subquery(other_status_at),
        old_tries=models.Count(
            'revisions',
            filter=(
                models.Q(revisions__created_at__gt=models.F('other_status_at')) |
                models.Q(other_status_at__isnull=True)
            ),
            distinct=True,
        ),
    )

    for participation in participations:
        # Use update() instead of save() to avoid auto_now
        Participation.objects.filter(pk=participation.pk).update(
            updated_at=participation.old_updated_at,
            created_at=participation.old_created_at,
            tries=participation.old_tries,
        )


class Migration(migrations.Migration):

    dependencies = [
        ('recruitment', '0015_appointment_verbose_name'),
    ]

    operations = [
        migrations.AddField(
            model_name='participation',
            name='created_at',
            field=castellum.utils.fields.DateTimeField(auto_now_add=True, default=django.utils.timezone.now, verbose_name='created at'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='participation',
            name='updated_at',
            field=castellum.utils.fields.DateTimeField(auto_now=True, verbose_name='updated at'),
        ),
        migrations.AddField(
            model_name='participation',
            name='tries',
            field=models.IntegerField(default=0, verbose_name='Tries'),
        ),
        migrations.RunPython(migrate_data),
        migrations.DeleteModel(
            name='ParticipationRevision',
        ),
    ]
